@@ -132,7 +132,7 @@ gpm_info_data_add_always (GpmInfoData *info_data,
 	if (value > 0) {
 		new->value = value;
 	} else {
-		gpm_debug ("Not recording a negative value (%i)", value);
+		gpm_debug ("Not recording value (%i)", value);
 		new->value = 0;
 	}
 	new->colour = colour;
@@ -381,7 +381,7 @@ gpm_info_data_finalize (GObject *object)
 	/* Free the graph data elements, the list, and also the graph data object */
 	GpmInfoDataPoint *point;
 	int a;
-	for (a=0; a > info_data->priv->array->len; a++) {
+	for (a=0; a < info_data->priv->array->len; a++) {
 		point = g_ptr_array_index (info_data->priv->array, a);
 		gpm_info_data_free_point (point);
 	}
