@@ -680,6 +680,10 @@ update_dpms_throttle (GpmManager *manager,
 			manager->priv->dpms_throttle_id = 0;
 		}
 	} else {
+		/* if throttle already exists then remove */
+		if (manager->priv->dpms_throttle_id > 0) {
+			gpm_screensaver_remove_throttle (manager->priv->screensaver, manager->priv->dpms_throttle_id);
+		}
 		manager->priv->dpms_throttle_id = gpm_screensaver_add_throttle (manager->priv->screensaver, _("Display power management activated"));
 	}
 }
@@ -735,6 +739,7 @@ change_power_policy (GpmManager *manager,
 		power_save = gconf_client_get_bool (client, GPM_PREF_BATTERY_LOWPOWER, NULL);
 	}
 
+	/* only do brightness changes if we have the hardware */
 	if (gpm_brightness_has_hardware (manager->priv->brightness)) {
 		gpm_brightness_set_level_std (manager->priv->brightness, brightness);
 		gpm_brightness_set (manager->priv->brightness);
@@ -1166,7 +1171,7 @@ gpm_manager_reboot (GpmManager *manager,
  **/
 static gboolean
 gpm_manager_hibernate (GpmManager *manager,
-			GError    **error)
+		       GError    **error)
 {
 	gboolean allowed;
 	gboolean ret;
@@ -1201,6 +1206,11 @@ gpm_manager_hibernate (GpmManager *manager,
 	if (! ret) {
 		char *message;
 		gboolean show_notify;
+
+		if (manager->priv->enable_beeping) {
+			gpm_warning_beep ();
+		}
+
 		/* We only show the HAL failed notification if set in gconf */
 		show_notify = gconf_client_get_bool (manager->priv->gconf_client,
 						     GPM_PREF_NOTIFY_HAL_ERROR, NULL);
@@ -1251,7 +1261,6 @@ gpm_manager_suspend (GpmManager *manager,
 	gboolean allowed;
 	gboolean ret;
 	gboolean do_lock;
-	gboolean show_notify;
 	GpmPowerStatus status;
 	char *message;
 	int charge_before_suspend;
@@ -1310,25 +1319,34 @@ gpm_manager_suspend (GpmManager *manager,
 		g_free (message);
 	}
 
-	/* We only show the HAL failed notification if set in gconf */
-	show_notify = gconf_client_get_bool (manager->priv->gconf_client,
-					     GPM_PREF_NOTIFY_HAL_ERROR, NULL);
-	if ((!ret) && show_notify) {
-		const char *title;
-		message = g_strdup_printf (_("Your computer failed to %s.\n"
-					     "Check the <a href=\"%s\">FAQ page</a> for common problems."),
-					     _("suspend"), GPM_FAQ_URL);
-		title = _("Suspend Problem");
-		gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
-				      title,
-				      message,
-				      GPM_NOTIFY_TIMEOUT_LONG,
-				      GTK_STOCK_DIALOG_WARNING,
-				      GPM_NOTIFY_URGENCY_LOW);
-		gpm_info_event_log (manager->priv->info,
-				    GPM_GRAPH_EVENT_NOTIFICATION,
-				    title);
-		g_free (message);
+	if (! ret) {
+		char *message;
+		gboolean show_notify;
+
+		if (manager->priv->enable_beeping) {
+			gpm_warning_beep ();
+		}
+
+		/* We only show the HAL failed notification if set in gconf */
+		show_notify = gconf_client_get_bool (manager->priv->gconf_client,
+						     GPM_PREF_NOTIFY_HAL_ERROR, NULL);
+		if (show_notify) {
+			const char *title;
+			message = g_strdup_printf (_("Your computer failed to %s.\n"
+						     "Check the <a href=\"%s\">FAQ page</a> for common problems."),
+						     _("suspend"), GPM_FAQ_URL);
+			title = _("Suspend Problem");
+			gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
+					      title,
+					      message,
+					      GPM_NOTIFY_TIMEOUT_LONG,
+					      GTK_STOCK_DIALOG_WARNING,
+					      GPM_NOTIFY_URGENCY_LOW);
+			gpm_info_event_log (manager->priv->info,
+					    GPM_GRAPH_EVENT_NOTIFICATION,
+					    title);
+			g_free (message);
+		}
 	}
 
 	if (do_lock) {
@@ -1707,9 +1725,6 @@ power_button_pressed_cb (GpmPower   *power,
 {
 	gpm_debug ("Button press event type=%s state=%d", type, state);
 
-	/* simulate user input */
-	gpm_screensaver_poke (manager->priv->screensaver);
-
 	if (strcmp (type, GPM_BUTTON_POWER) == 0) {
 		power_button_pressed (manager);
 
@@ -1977,6 +1992,7 @@ battery_status_changed_primary (GpmManager     *manager,
 	   drops down to 95% as some batteries charge to 100% and then fluctuate
 	   from ~98% to 100%. See #338281 for details */
 	if (battery_status->percentage_charge < 95 &&
+	    battery_status->percentage_charge > 0 &&
 	    gpm_power_battery_is_charged (battery_status) == FALSE) {
 		manager->priv->done_notify_fully_charged = FALSE;
 	}
@@ -2070,12 +2086,13 @@ battery_status_changed_primary (GpmManager     *manager,
 
 	/* If we had a message, print it as a notification */
 	if (message) {
-		const char *icon;
+		char *icon;
 		title = battery_low_get_title (warning_type);
 		icon = gpm_power_get_icon_from_status (battery_status, battery_kind);
 		gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
 				      title, message, timeout,
 				      icon, GPM_NOTIFY_URGENCY_NORMAL);
+		g_free (icon);
 		if (manager->priv->enable_beeping) {
 			gpm_warning_beep ();
 		}
@@ -2180,7 +2197,7 @@ battery_status_changed_ups (GpmManager	   *manager,
 
 	/* If we had a message, print it as a notification */
 	if (message) {
-		const char *icon;
+		char *icon;
 		title = battery_low_get_title (warning_type);
 		icon = gpm_power_get_icon_from_status (battery_status, battery_kind);
 		gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
@@ -2192,6 +2209,7 @@ battery_status_changed_ups (GpmManager	   *manager,
 		gpm_info_event_log (manager->priv->info,
 				    GPM_GRAPH_EVENT_NOTIFICATION,
 				    title);
+		g_free (icon);
 		g_free (message);
 	}
 }
@@ -2215,7 +2233,7 @@ battery_status_changed_misc (GpmManager	    	   *manager,
 	char *message = NULL;
 	const char *title = NULL;
 	const char *name;
-	const char *icon;
+	char *icon;
 
 	/* mouse, keyboard and PDA have no time, just percentage */
 	warning_type = gpm_manager_get_warning_type (manager, battery_status, FALSE);
@@ -2277,6 +2295,7 @@ battery_status_changed_misc (GpmManager	    	   *manager,
 	}
 	gpm_info_event_log (manager->priv->info, GPM_GRAPH_EVENT_NOTIFICATION, title);
 
+	g_free (icon);
 	g_free (message);
 }
 
@@ -2584,24 +2603,29 @@ screensaver_auth_request_cb (GpmScreensaver *screensaver,
 			     gboolean        auth,
 			     GpmManager     *manager)
 {
-	GError *error;
+	GError  *error;
+	gboolean res;
+
+	/* Only act on the begin authentication request */
+	if (! auth) {
+		return;
+	}
 
 	/* TODO: This may be a bid of a bodge, as we will have multiple
 		 resume requests -- maybe this need a logic cleanup */
-	if (auth) {
-		if (gpm_brightness_has_hardware (manager->priv->brightness)) {
-			gpm_debug ("undimming lcd due to auth begin");
-			gpm_brightness_undim (manager->priv->brightness);
-		}
+	if (gpm_brightness_has_hardware (manager->priv->brightness)) {
+		gpm_debug ("undimming lcd due to auth begin");
+		gpm_brightness_undim (manager->priv->brightness);
+	}
 
-		/* We turn on the monitor unconditionally, as we may be using
-		 * a smartcard to authenticate and DPMS might still be on.
-		 * See #350291 for more details */
-		gpm_dpms_set_mode (manager->priv->dpms, GPM_DPMS_MODE_ON, &error);
-		if (error) {
-			gpm_warning ("Failed to turn on DPMS: %s", error->message);
-			g_error_free (error);
-		}
+	/* We turn on the monitor unconditionally, as we may be using
+	 * a smartcard to authenticate and DPMS might still be on.
+	 * See #350291 for more details */
+	error = NULL;
+	res = gpm_dpms_set_mode (manager->priv->dpms, GPM_DPMS_MODE_ON, &error);
+	if (! res) {
+		gpm_warning ("Failed to turn on DPMS: %s", error->message);
+		g_error_free (error);
 	}
 }
 
@@ -2639,22 +2663,6 @@ hal_daemon_monitor_cb (GpmHal     *hal,
 	tray_icon_update (manager);
 }
 
-/**
- * manager_rescan_buttons:
- * @manager: This manager class instance
- *
- * Rescan the buttons to avoid #346082
- *
- * Return value: TRUE, as we want to repeat this action on resume.
- **/
-static gboolean
-manager_rescan_buttons (GpmManager *manager)
-{
-	g_debug ("rescanning buttons");
-	gpm_hal_device_rescan_capability (manager->priv->hal, "button");
-	return TRUE;
-}
-
 /**
  * gpm_manager_init:
  * @manager: This manager class instance
@@ -2860,9 +2868,8 @@ gpm_manager_init (GpmManager *manager)
 	/* Do we ignore inhibit requests? */
 	manager->priv->ignore_inhibits = gconf_client_get_bool (manager->priv->gconf_client,
 								GPM_PREF_IGNORE_INHIBITS, NULL);
-
-	/* poll the lid periodically to avoid #346082 */
-	g_timeout_add (1000 * 60, (GSourceFunc) manager_rescan_buttons, manager);
+	/* set no throttle */
+	manager->priv->dpms_throttle_id = -1;
 }
 
 /**
